/**
 * Copyright (c) 2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.extension.bcgateway;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.IOException;

import org.apache.commons.io.FileUtils;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Unit test about the legal information that the archive must contain
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class LegalIT {

    private final static String PROPERTY_NAME_ARCHIVE_BASE_DIRECTORY = "archive-base-directory";

    private static File ARCHIVE_BASE_DIRECTORY = null;

    @BeforeClass
    public static void setup() {
        final String archiveBaseDirectoryStr = System.getProperty(PROPERTY_NAME_ARCHIVE_BASE_DIRECTORY);
        assertNotNull("System property '" + PROPERTY_NAME_ARCHIVE_BASE_DIRECTORY + "' not set.",
                archiveBaseDirectoryStr);
        ARCHIVE_BASE_DIRECTORY = new File(archiveBaseDirectoryStr);
        assertTrue("The archive base directory '" + ARCHIVE_BASE_DIRECTORY.getAbsolutePath() + "' does not exist",
                ARCHIVE_BASE_DIRECTORY.exists());
        assertTrue("The archive base directory '" + ARCHIVE_BASE_DIRECTORY.getAbsolutePath() + "' is not a directory",
                ARCHIVE_BASE_DIRECTORY.isDirectory());
    }

    /**
     * <p>
     * Verify that a file 'LICENSE' exists.
     * </p>
     */
    @Test
    public void licenseFile() throws IOException {
        
        final File licenseFile = new File(ARCHIVE_BASE_DIRECTORY, "LICENSE");
        assertTrue("'LICENSE' file missing", FileUtils.directoryContains(ARCHIVE_BASE_DIRECTORY, licenseFile));
        assertTrue("Too short file 'LICENSE'", FileUtils.sizeOf(licenseFile) > 20000);
    }

    /**
     * <p>
     * Verify that a file 'THIRD-PARTY' exists.
     * </p>
     */
    @Test
    public void thirdPartyFile() throws IOException {

        final File thirdPartyFile = new File(ARCHIVE_BASE_DIRECTORY, "THIRD-PARTY");
        assertTrue("'THIRD-PARTY' file missing", FileUtils.directoryContains(ARCHIVE_BASE_DIRECTORY, thirdPartyFile));
        assertTrue("Too short file 'THIRD-PARTY'", FileUtils.sizeOf(thirdPartyFile) > 2000);
    }

    /**
     * <p>
     * Verify that license files of third party are packaged.
     * </p>
     */
    @Test
    public void thirdPartyLicenseFiles() throws IOException {

        final File thirdPartyLIcenseFiles = new File(ARCHIVE_BASE_DIRECTORY, "licenses");
        assertTrue("3PP licenses missing", FileUtils.directoryContains(ARCHIVE_BASE_DIRECTORY, thirdPartyLIcenseFiles));
        assertTrue("Not enough different 3PP licenses", thirdPartyLIcenseFiles.listFiles().length > 4);
        assertTrue("Too many different 3PP licenses", thirdPartyLIcenseFiles.listFiles().length < 15);
    }

    /**
     * <p>
     * Verify that a file 'COPYRIGHT' exists.
     * </p>
     */
    @Test
    public void copyrightFile() throws IOException {

        final File copyrightFile = new File(ARCHIVE_BASE_DIRECTORY, "COPYRIGHT");
        assertTrue("'COPYRIGHT' file missing", FileUtils.directoryContains(ARCHIVE_BASE_DIRECTORY, copyrightFile));
        assertTrue("Too short file 'COPYRIGHT'", FileUtils.sizeOf(copyrightFile) > 500);
        assertTrue("Too long file 'COPYRIGHT'", FileUtils.sizeOf(copyrightFile) < 1000);
    }

}
